module Main where

import Control.Monad
import Control.Concurrent (threadDelay)

import System.Random

import qualified Graphics.UI.Threepenny as UI
import Graphics.UI.Threepenny.Core

import Minesweeper

main :: IO ()
main = do
    startGUI defaultConfig {jsStatic = Just "view"} setup

setup :: Window -> UI ()
setup w = void $ do
    return w # set title "Minesweeper"

    UI.addStyleSheet w "bootstrap.min.css"
    UI.addStyleSheet w "minesweeper.css"

    rng <- liftIO newStdGen
    let board = uncover (createBoard 30 0.15 rng) (4,4)

    getBody w #+ [
        UI.div #. "container" #+ [
            UI.h1 #+ [string "Minesweeper"],
            --UI.h4 #+ [string "By Jack Harley <jharley@tcd.ie>"],
            gameGridTable board
        ]]

gameGridTable :: Board -> UI Element
gameGridTable b = mkElement "table" #+ rows b

rows :: Board -> [UI Element]
rows b = rows' b 0
rows' b r | r < size b = (mkElement "tr" #+ cells b r) : rows' b (r+1)
          | otherwise = []

cells :: Board -> Int -> [UI Element]
cells b r = cells' b r 0
cells' b r c | c < size b = mkElement "td" #. (squareBgColour b (r,c) ++ " " ++ squareTextColour b (r,c)) 
                                           #+ [string $ squareAscii b (r,c)] : cells' b r (c+1)
             | otherwise = []